@@ -2,7 +2,7 @@ package WebService::HipChat;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '0.0900'; # VERSION
+our $VERSION = '0.1000'; # VERSION
 
 use Carp qw(croak);
 use MIME::Entity;
@@ -122,6 +122,12 @@ sub get_user {
     return $self->get("/user/$user");
 }
 
+sub delete_user {
+    my ($self, $user) = @_;
+    croak '$user is required' unless $user;
+    return $self->delete("/user/$user");
+}
+
 sub send_private_msg {
     my ($self, $user, $data) = @_;
     croak '$user is required' unless $user;
@@ -129,6 +135,19 @@ sub send_private_msg {
     return $self->post("/user/$user/message", $data);
 }
 
+sub send_room_msg {
+    my ($self, $room, $data) = @_;
+    croak '$room is required' unless $room;
+    croak '$data is required' unless 'HASH' eq ref $data;
+    return $self->post("/room/$room/message", $data);
+}
+
+sub get_private_history {
+    my ($self, $user, %args) = @_;
+    croak '$user is required' unless $user;
+    return $self->get("/user/$user/history", $args{query} || {});
+}
+
 sub get_emoticons {
     my ($self, %args) = @_;
     return $self->get("/emoticon", $args{query} || {});
@@ -221,7 +240,7 @@ WebService::HipChat
 
 =head1 VERSION
 
-version 0.0900
+version 0.1000
 
 =head1 SYNOPSIS
 
@@ -388,6 +407,57 @@ Example response:
 
     send_private_msg($user, { message => 'allo' });
 
+=head2 send_room_msg
+
+    send_room_msg($room, { message => 'allo' });
+
+=head2 get_private_history
+
+    $hc->get_private_history($user)
+    $hc->get_private_history($user, query => { 'max-results' => 5 });
+
+Example response:
+
+   {
+    items        [
+        [0] {
+            date       "2014-11-13T10:48:33.322506+00:00",
+            from       {
+                id             123456,
+                links          {
+                    self   "https://api.hipchat.com/v2/user/123456"
+                },
+                mention_name   "Bob",
+                name           "Bob Williams"
+            },
+            id         "38988c8c-9120-44ce-87c5-6731a7a3b6",
+            mentions   [],
+            message    "heres a message and a link http://www.sun.com/",
+            type       "message"
+        },
+        [1] {
+            date       "2014-11-13T10:49:02.377436+00:00",
+            from       {
+                id             123456,
+                links          {
+                    self   "https://api.hipchat.com/v2/user/123456"
+                },
+                mention_name   "Bob",
+                name           "Bob Williams"
+            },
+            id         "c1f47537-6506-4f46-b820-eaade5adc5",
+            mentions   [],
+            message    "A message",
+            type       "message"
+        }
+    ],
+    links        {
+        self   "https://api.hipchat.com/v2/user/123456/history"
+    },
+    maxResults   5,
+    startIndex   0
+   }
+
 =head2 get_members
 
     get_members($room);
@@ -491,6 +561,10 @@ Example response:
       xmpp_jid       => '1_1@chat.hipchat.com',
     }
 
+=head2 delete_user
+
+    delete_user($user)
+
 =head2 get_emoticons
 
     get_emoticons()
@@ -606,7 +680,13 @@ Example:
 
 =over
 
-=item Chris Hughes <chris@lokku.com>
+=item Chris C. <https://github.com/centreti>
+
+=item Chris Hughes <https://github.com/chrisspang>
+
+=item Ken-ichi Mito <https://github.com/mittyorz>
+
+=item Tim Man <https://github.com/teebszet>
 
 =back
 
